---
myst:
  html_meta:
    "description lang=en": |
        API documentation for RedisVL
---

# RedisVL API

Reference documentation for the RedisVL API.

```{toctree}
:caption: RedisVL API
:maxdepth: 2

schema
searchindex
vector
query
filter
vectorizer
reranker
cache
message_history
router
```

